@@ -1,7 +1,7 @@
 import click
 
 from taskforge.commands.cli import cli
-from taskforge.commands.utils import coro, inject_client
+from taskforge.commands.utils import inject_client
 
 
 @cli.command(aliases=["a"])
@@ -9,9 +9,8 @@ from taskforge.commands.utils import coro, inject_client
 @click.option("-c", "--context", "context", default=None, type=str)
 @click.option("-p", "--priority", "priority", default=1, type=int)
 @click.argument("title", nargs=-1, required=True, type=str)
-@coro
 @inject_client
-async def add(
+def add(
     title,
     top,
     context,
@@ -27,14 +26,14 @@ async def add(
     }
 
     if context:
-        ctx = await client.contexts.get_by_name(context)
+        ctx = client.contexts.get_by_name(context)
         task["context"] = ctx["id"]
 
     if top:
-        current = await client.tasks.next(context=context)
+        current = client.tasks.next(context=context)
         task["priority"] = current["priority"] + 1
 
-    created = await client.tasks.create(task)
+    created = client.tasks.create(task)
     msg = "Created: {} {}".format(
         created["id"],
         created["title"],
